Module interval

Module interval 

Intervals that can be added to or subtracted from dates.

In addition, dates can be subtracted from one another, and the result is a DateInterval.

Structs

DateInterval
An interval of days.
MonthInterval
An interval of months.